@@ -107,7 +107,7 @@ OrderType = Literal[
 Hex = str  # Assuming Hex is just a string type in Python
 
 TimeInForce = Literal["GTC", "FOK", "IOC", "PostOnly"]
-OrderSide = Literal["Long", "Short"] 
+OrderSide = Literal["Long", "Short"]
 
 OrderRequest = TypedDict("OrderRequest", {
     "symbol": str,
@@ -193,11 +193,13 @@ class PlaceOrderResponse(TypedDict):
 
 OrderSideType = Literal["BUY", "SELL"]
 
+
 class CollateralInfo(TypedDict):
     asset: str
     collateral_id: str
     amount: str
 
+
 class OpenOrderInfo(TypedDict):
     order_digest: str
     symbol: str
@@ -206,12 +208,14 @@ class OpenOrderInfo(TypedDict):
     original_quantity: str
     remaining_quantity: str
 
+
 class PositionInfo(TypedDict):
     symbol: str
     side: OrderSide
     entry_price: str
     quantity: str
 
+
 class SubAccountSummary(TypedDict):
     open_orders: List[OpenOrderInfo]
     collaterals: List[CollateralInfo]
@@ -226,8 +230,19 @@ class SubAccountSummary(TypedDict):
     position_imr: str
     position_mmr: str
 
-NetworkOption = Literal["mainnet", "testnet"]
-ChainOption = Literal["base", "arbitrumSepolia"]
+
+NetworkOption = Literal[
+   "mainnet", 
+   "mainnetBase",
+   "mainnetArbitrum",
+   "mainnetBsc",
+   "base",
+   "arbitrum",
+   "bsc"
+]
+
+ChainOption = Literal["base"]
+
 
 class MarketInfo(TypedDict):
     id: int
@@ -242,16 +257,19 @@ class MarketInfo(TypedDict):
     lot_size: str
     min_notional_size: str
 
+
 class MarkPrice(TypedDict):
     symbol: str
     mark_price: str
     index_price: str
 
+
 class TokenAddress(TypedDict):
     chain: str
     chain_id: int
     address: str
 
+
 class CollateralInfo(TypedDict):
     asset: str
     collateral_id: str
@@ -264,6 +282,7 @@ class CollateralInfo(TypedDict):
     withdrawal_base_fee: str
     priority: int
 
+
 class LastTrade(TypedDict):
     id: int
     symbol: str
@@ -272,6 +291,7 @@ class LastTrade(TypedDict):
     is_buyer_maker: bool
     time: int
 
+
 class CurrentFundingRate(TypedDict):
     symbol: str
     index_price: str
@@ -281,12 +301,14 @@ class CurrentFundingRate(TypedDict):
     next_funding_timestamp: int
     timestamp: int
 
+
 class HistoricalFundingRate(TypedDict):
     funding_rate: str
     apr: str
     avg_premium_index: str
     created_at: int
 
+
 class TradeHistory(TypedDict):
     symbol: str
     side: str
@@ -296,4 +318,4 @@ class TradeHistory(TypedDict):
     trading_fee_token: str
     realized_pnl: str
     is_taker: bool
-    traded_at: int
\ No newline at end of file
+    traded_at: int
